@@ -20,14 +20,14 @@
 
 #include "alarmlistdelegate.h"
 
-#include "akonadimodel.h"
 #include "functions.h"
+#include "resources/resourcedatamodelbase.h"
 #include "resources/eventmodel.h"
 #include "kalarm_debug.h"
 
-#include <kalarmcal/kacalendar.h>
+#include <KAlarmCal/KACalendar>
 
-#include <kcolorscheme.h>
+#include <KColorScheme>
 
 #include <QPainter>
 
