@@ -22,16 +22,16 @@
 
 #include "alarmlistview.h"
 #include "eventlistview.h"
-#include "messagebox.h"
 #include "preferences.h"
 #include "resources/eventmodel.h"
+#include "lib/messagebox.h"
 #include "kalarm_debug.h"
 
-#include <kalarmcal/kaevent.h>
+#include <KAlarmCal/KAEvent>
 
-#include <kfinddialog.h>
-#include <kfind.h>
-#include <kseparator.h>
+#include <KFindDialog>
+#include <KFind>
+#include <KSeparator>
 #include <kwindowsystem.h>
 #include <KLocalizedString>
 
