@@ -1,7 +1,7 @@
 /*
  *  resource.h  -  generic class containing an alarm calendar resource
  *  Program:  kalarm
- *  Copyright © 2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2019-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -56,12 +56,26 @@ public:
     /** Return whether the resource has a null calendar resource pointer. */
     bool isNull() const;
 
-    /** Return whether the resource has a valid configuration. */
+    /** Return whether the resource has a valid configuration.
+     *  Note that the resource may be unusable even if it has a valid
+     *  configuration: see failed().
+     */
     bool isValid() const;
 
+    /** Return whether the resource has a fatal error.
+     *  Note that failed() will return true if the configuration is invalid
+     *  (i.e. isValid() returns false). It will also return true if some other
+     *  error prevents the resource being used, e.g. if the calendar file
+     *  cannot be created.
+     */
+    bool failed() const;
+
     /** Return the resource's unique ID. */
     ResourceId id() const;
 
+    /** Return the resource's unique ID, as shown to the user. */
+    ResourceId displayId() const;
+
     /** Return the type of storage used by the resource. */
     StorageType storageType() const;
 
@@ -72,6 +86,11 @@ public:
      */
     QString storageTypeString(bool description) const;
 
+    /** Return the type description of a resource (file, remote file, etc.)
+     *  for display purposes. This is equivalent to storageTypeString(true).
+     */
+    static QString storageTypeString(ResourceType::StorageType);
+
     /** Return the location(s) of the resource (URL, file path, etc.) */
     QUrl location() const;
 
@@ -149,11 +168,11 @@ public:
 #endif
 
     /** Return whether the user has chosen not to update the resource's
-     *  calendar storage formst. */
+     *  calendar storage format. */
     bool keepFormat() const;
 
     /** Set or clear whether the user has chosen not to update the resource's
-     *  calendar storage formst. */
+     *  calendar storage format. */
     void setKeepFormat(bool keep);
 
     /** Return the background colour used to display alarms belonging to
@@ -227,6 +246,11 @@ public:
      */
     void configSetStandard(CalEvent::Types types);
 
+    /** Return whether the resource is in the current KAlarm format.
+     *  @see compatibility(), compatibilityVersion()
+     */
+    bool isCompatible() const;
+
     /** Return whether the resource is in a different format from the
      *  current KAlarm format, in which case it cannot be written to.
      *  Note that isWritable() takes account of incompatible format
@@ -234,8 +258,13 @@ public:
      */
     KACalendar::Compat compatibility() const;
 
-    /** Return whether the resource is in the current KAlarm format. */
-    bool isCompatible() const;
+    /** Return whether the resource is in a different format from the
+     *  current KAlarm format, in which case it cannot be written to.
+     *  Note that isWritable() takes account of incompatible format
+     *  as well as read-only and enabled statuses.
+     *  @param versionString  Receives calendar's KAlarm version as a string.
+     */
+    KACalendar::Compat compatibilityVersion(QString& versionString) const;
 
     /** Edit the resource's configuration. */
     void editResource(QWidget* dialogParent);
@@ -261,10 +290,8 @@ public:
      */
     bool load(bool readThroughCache = true);
 
-#if 0
     /** Reload the resource. Any cached data is first discarded. */
     bool reload();
-#endif
 
     /** Return whether the resource has fully loaded. */
     bool isPopulated() const;
@@ -283,6 +310,11 @@ public:
     /** Return whether the resource is waiting for a save() to complete. */
     bool isSaving() const;
 
+    /** Close the resource. This saves any unsaved data.
+     *  Saving is not performed if the resource is disabled.
+     */
+    void close();
+
     /** Return all events belonging to this resource. */
     QList<KAEvent> events() const;
 
