@@ -20,22 +20,24 @@
 
 #include "templatedlg.h"
 
-#include "editdlg.h"
 #include "alarmcalendar.h"
+#include "editdlg.h"
 #include "functions.h"
-#include "messagebox.h"
 #include "newalarmaction.h"
-#include "shellprocess.h"
 #include "templatelistview.h"
 #include "undo.h"
+#include "resources/datamodel.h"
 #include "resources/resources.h"
 #include "resources/eventmodel.h"
+#include "lib/config.h"
+#include "lib/messagebox.h"
+#include "lib/shellprocess.h"
 #include "kalarm_debug.h"
 
 #include <KLocalizedString>
-#include <kguiitem.h>
-#include <kstandardaction.h>
-#include <kactioncollection.h>
+#include <KGuiItem>
+#include <KStandardAction>
+#include <KActionCollection>
 #include <KSeparator>
 
 #include <QAction>
@@ -67,7 +69,7 @@ TemplateDlg::TemplateDlg(QWidget* parent)
     QBoxLayout* layout = new QVBoxLayout();
     layout->setContentsMargins(0, 0, 0, 0);
     hlayout->addLayout(layout);
-    mListFilterModel = TemplateListModel::create<AkonadiModel>(this);
+    mListFilterModel = DataModel::createTemplateListModel(this);
     if (!ShellProcess::authorised())
         mListFilterModel->setAlarmActionFilter(static_cast<KAEvent::Actions>(KAEvent::ACT_ALL & ~KAEvent::ACT_COMMAND));
     mListView = new TemplateListView(this);
@@ -122,7 +124,7 @@ TemplateDlg::TemplateDlg(QWidget* parent)
     slotSelectionChanged();          // enable/disable buttons as appropriate
 
     QSize s;
-    if (KAlarm::readConfigWindowSize(TMPL_DIALOG_NAME, s))
+    if (Config::readWindowSize(TMPL_DIALOG_NAME, s))
         resize(s);
 }
 
@@ -234,7 +236,7 @@ void TemplateDlg::slotSelectionChanged()
 void TemplateDlg::resizeEvent(QResizeEvent* re)
 {
     if (isVisible())
-        KAlarm::writeConfigWindowSize(TMPL_DIALOG_NAME, re->size());
+        Config::writeWindowSize(TMPL_DIALOG_NAME, re->size());
     QDialog::resizeEvent(re);
 }
 
