@@ -20,11 +20,12 @@
 
 #include "templatepickdlg.h"
 
-#include "akonadimodel.h"
 #include "functions.h"
-#include "shellprocess.h"
 #include "templatelistview.h"
+#include "resources/datamodel.h"
 #include "resources/eventmodel.h"
+#include "lib/config.h"
+#include "lib/shellprocess.h"
 #include "kalarm_debug.h"
 
 #include <KLocalizedString>
@@ -62,7 +63,7 @@ TemplatePickDlg::TemplatePickDlg(KAEvent::Actions type, QWidget* parent)
         type = static_cast<KAEvent::Actions>(type & ~KAEvent::ACT_COMMAND);
         shown = static_cast<KAEvent::Actions>(shown & ~KAEvent::ACT_COMMAND);
     }
-    mListFilterModel = TemplateListModel::create<AkonadiModel>(this);
+    mListFilterModel = DataModel::createTemplateListModel(this);
     mListFilterModel->setAlarmActionsEnabled(type);
     mListFilterModel->setAlarmActionFilter(shown);
     mListView = new TemplateListView(topWidget);
@@ -79,7 +80,7 @@ TemplatePickDlg::TemplatePickDlg(KAEvent::Actions type, QWidget* parent)
     slotSelectionChanged();        // enable or disable the OK button
 
     QSize s;
-    if (KAlarm::readConfigWindowSize(TMPL_PICK_DIALOG_NAME, s))
+    if (Config::readWindowSize(TMPL_PICK_DIALOG_NAME, s))
         resize(s);
 }
 
@@ -110,7 +111,7 @@ void TemplatePickDlg::slotSelectionChanged()
 void TemplatePickDlg::resizeEvent(QResizeEvent* re)
 {
     if (isVisible())
-        KAlarm::writeConfigWindowSize(TMPL_PICK_DIALOG_NAME, re->size());
+        Config::writeWindowSize(TMPL_PICK_DIALOG_NAME, re->size());
     QDialog::resizeEvent(re);
 }
 
